@@ -15,7 +15,10 @@ import cdk_nag._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pdk-nag", "0.12.9", __name__[0:-6], "pdk-nag@0.12.9.jsii.tgz"
+    "@aws-prototyping-sdk/pdk-nag",
+    "0.12.11",
+    __name__[0:-6],
+    "pdk-nag@0.12.11.jsii.tgz",
 )
 
 __all__ = [
